# W2V Utility Classes

I have encountered many machine learning tasks that use the basic
word2vec and negative sampling structure to learn embeddings.

I built the code here to facilitate working with such datasets.
I have tried to make it generic and extensible,
so that it is applicable to
the variety of cases I encounter in my research.
